@@ -14,7 +14,7 @@ def read_yaml(yaml_dir: str):
 
 
 def read_json():
-    json_dir = './laugh.json'
+    json_dir = 'laugh.json'
     json_data = json.load(open(json_dir, 'r'))
     return json_data
 
